@@ -1,8 +1,6 @@
 {-DHUN| module for parallel computations. The paralellism is reached by forking threads with liftIO. When starting a thread and empty MVar is returned immediately. The MVar is filled on completing of the thread. Normal function can be lifted to threaded function operation on MVar of the parameters instead of the parameters themself. Thus it is possible to define dependencies of function on the return values of other functions and let the order of excecution evolove automatically, so a function is called as soon as all its parameters have been calculated. All functions considered in this module are understood to have an IO return type. This module is mainly used for paraller downloading from the web. DHUN-}
 module Parallel where
 import Control.Concurrent.MVar
-import Control.Concurrent
-import Control.DeepSeq
  
 {-DHUN| takes a function of return type IO which takes on parameter and an MVar containing at the same type as the parameter of the function and returns and IO action containing an MVar containing the same type as the tyoe contained in the IO Action returned by the function. This function retuns immediately and passed an empty MVar as return type. As soon as the MVar containing the same type as the parameter of the function is ready for reading the the function is executed in a new thread. As soon as the function return a value, the it is written into the returned MVar.  DHUN-}
  
@@ -35,7 +33,7 @@ ppure vv x
 {-DHUN| alias to switch between forkOS and forkIO for testing DHUN-}
 
 myFork :: MVar Int ->  IO () -> IO ()
-myFork v x = x
+myFork _ x = x
 
 
 
